@@ -28,7 +28,7 @@ from adafruit_io.adafruit_io_errors import (
 )
 
 __version__ = "0.0.0-auto.0"
-__repo__ = "https://github.com/adafruit/Adafruit_CircuitPython_Adafruit_IO.git"
+__repo__ = "https://github.com/adafruit/Adafruit_CircuitPython_AdafruitIO.git"
 
 CLIENT_HEADERS = {"User-Agent": "AIO-CircuitPython/{0}".format(__version__)}
 
@@ -51,9 +51,9 @@ class IO_MQTT:
             raise TypeError(
                 "This class requires a MiniMQTT client object, please create one."
             )
-        # MiniMQTT's username kwarg is optional, IO requires a username
+        # Adafruit IO MQTT API MUST require a username
         try:
-            self._user = self._client.user
+            self._user = self._client._username
         except Exception as err:
             raise TypeError(
                 "Adafruit IO requires a username, please set one in MiniMQTT"
@@ -70,11 +70,6 @@ class IO_MQTT:
         self._client.on_message = self._on_message_mqtt
         self._client.on_subscribe = self._on_subscribe_mqtt
         self._client.on_unsubscribe = self._on_unsubscribe_mqtt
-        self._logger = False
-        # Write to the MiniMQTT logger, if avaliable.
-        if self._client.logger is not None:
-            self._logger = True
-            self._client.set_logger_level("DEBUG")
         self._connected = False
 
     def __enter__(self):
@@ -112,8 +107,6 @@ class IO_MQTT:
     # pylint: disable=not-callable, unused-argument
     def _on_connect_mqtt(self, client, userdata, flags, return_code):
         """Runs when the client calls on_connect."""
-        if self._logger:
-            self._client._logger.debug("Client called on_connect.")
         if return_code == 0:
             self._connected = True
         else:
@@ -125,8 +118,6 @@ class IO_MQTT:
     # pylint: disable=not-callable, unused-argument
     def _on_disconnect_mqtt(self, client, userdata, return_code):
         """Runs when the client calls on_disconnect."""
-        if self._logger:
-            self._client._logger.debug("Client called on_disconnect")
         self._connected = False
         # Call the user-defined on_disconnect callblack if defined
         if self.on_disconnect is not None:
@@ -140,8 +131,6 @@ class IO_MQTT:
         :param str topic: MQTT topic response from Adafruit IO.
         :param str payload: MQTT payload data response from Adafruit IO.
         """
-        if self._logger:
-            self._client._logger.debug("Client called on_message.")
         if self.on_message is not None:
             # Parse the MQTT topic string
             topic_name = topic.split("/")
@@ -177,16 +166,12 @@ class IO_MQTT:
     # pylint: disable=not-callable
     def _on_subscribe_mqtt(self, client, user_data, topic, qos):
         """Runs when the client calls on_subscribe."""
-        if self._logger:
-            self._client._logger.debug("Client called on_subscribe")
         if self.on_subscribe is not None:
             self.on_subscribe(self, user_data, topic, qos)
 
     # pylint: disable=not-callable
     def _on_unsubscribe_mqtt(self, client, user_data, topic, pid):
         """Runs when the client calls on_unsubscribe."""
-        if self._logger:
-            self._client._logger.debug("Client called on_unsubscribe")
         if self.on_unsubscribe is not None:
             self.on_unsubscribe(self, user_data, topic, pid)
 
@@ -202,7 +187,7 @@ class IO_MQTT:
 
         """
         self._client.add_topic_callback(
-            "{0}/feeds/{1}".format(self._user, feed_key), callback_method
+            "{0}/f/{1}".format(self._user, feed_key), callback_method
         )
 
     def remove_feed_callback(self, feed_key):
@@ -214,7 +199,7 @@ class IO_MQTT:
         :param str feed_key: Adafruit IO feed key.
 
         """
-        self._client.remove_topic_callback("{0}/feeds/{1}".format(self._user, feed_key))
+        self._client.remove_topic_callback("{0}/f/{1}".format(self._user, feed_key))
 
     def loop(self):
         """Manually process messages from Adafruit IO.
@@ -251,11 +236,11 @@ class IO_MQTT:
             client.subscribe([('temperature'), ('humidity')])
         """
         if shared_user is not None and feed_key is not None:
-            self._client.subscribe("{0}/feeds/{1}".format(shared_user, feed_key))
+            self._client.subscribe("{0}/f/{1}".format(shared_user, feed_key))
         elif group_key is not None:
-            self._client.subscribe("{0}/groups/{1}".format(self._user, group_key))
+            self._client.subscribe("{0}/g/{1}".format(self._user, group_key))
         elif feed_key is not None:
-            self._client.subscribe("{0}/feeds/{1}".format(self._user, feed_key))
+            self._client.subscribe("{0}/f/{1}".format(self._user, feed_key))
         else:
             raise AdafruitIO_MQTTError("Must provide a feed_key or group_key.")
 
@@ -297,12 +282,10 @@ class IO_MQTT:
         Information about these topics can be found on the Adafruit IO MQTT API Docs.:
         https://io.adafruit.com/api/docs/mqtt.html#time-topics
         """
-        if "seconds" or "millis" or "hours" in time_type:
-            self._client.subscribe("time/" + time_type)
-        elif time_type == "iso":
+        if time_type == "iso":
             self._client.subscribe("time/ISO-8601")
         else:
-            raise TypeError("Invalid time feed type specified")
+            self._client.subscribe("time/" + time_type)
 
     def unsubscribe(self, feed_key=None, group_key=None, shared_user=None):
         """Unsubscribes from an Adafruit IO feed or group.
@@ -332,11 +315,11 @@ class IO_MQTT:
 
         """
         if shared_user is not None and feed_key is not None:
-            self._client.unsubscribe("{0}/feeds/{1}".format(shared_user, feed_key))
+            self._client.unsubscribe("{0}/f/{1}".format(shared_user, feed_key))
         elif group_key is not None:
-            self._client.unsubscribe("{0}/groups/{1}".format(self._user, feed_key))
+            self._client.unsubscribe("{0}/g/{1}".format(self._user, feed_key))
         elif feed_key is not None:
-            self._client.unsubscribe("{0}/feeds/{1}".format(self._user, feed_key))
+            self._client.unsubscribe("{0}/f/{1}".format(self._user, feed_key))
         else:
             raise AdafruitIO_MQTTError("Must provide a feed_key or group_key.")
 
@@ -416,18 +399,18 @@ class IO_MQTT:
 
         """
         if is_group:
-            self._client.publish("{0}/groups/{1}".format(self._user, feed_key), data)
+            self._client.publish("{0}/g/{1}".format(self._user, feed_key), data)
         if shared_user is not None:
-            self._client.publish("{0}/feeds/{1}".format(shared_user, feed_key), data)
+            self._client.publish("{0}/f/{1}".format(shared_user, feed_key), data)
         if metadata is not None:
             if isinstance(data, int or float):
                 data = str(data)
             csv_string = data + "," + metadata
             self._client.publish(
-                "{0}/feeds/{1}/csv".format(self._user, feed_key), csv_string
+                "{0}/f/{1}/csv".format(self._user, feed_key), csv_string
             )
         else:
-            self._client.publish("{0}/feeds/{1}".format(self._user, feed_key), data)
+            self._client.publish("{0}/f/{1}".format(self._user, feed_key), data)
 
     def get(self, feed_key):
         """Calling this method will make Adafruit IO publish the most recent
@@ -440,7 +423,7 @@ class IO_MQTT:
 
             io.get('temperature')
         """
-        self._client.publish("{0}/feeds/{1}/get".format(self._user, feed_key), "\0")
+        self._client.publish("{0}/f/{1}/get".format(self._user, feed_key), "\0")
 
 
 class IO_HTTP:
@@ -472,16 +455,16 @@ class IO_HTTP:
 
     @staticmethod
     def _create_data(data, metadata):
-        """Creates JSON data payload"""
-        if metadata is not None:
-            return {
-                "value": data,
-                "lat": metadata["lat"],
-                "lon": metadata["lon"],
-                "ele": metadata["ele"],
-                "created_at": metadata["created_at"],
-            }
-        return {"value": data}
+        """Returns a data payload as expected by the Adafruit IO HTTP API
+        :param data: Payload value.
+        :param dict metadata: Payload metadata.
+
+        """
+        payload = {"value": data}
+        if metadata:  # metadata is expected as a dict, append key/vals
+            for k, val in metadata.items():
+                payload[k] = val
+        return payload
 
     @staticmethod
     def _handle_error(response):
@@ -589,16 +572,6 @@ class IO_HTTP:
         return self._delete(path)
 
     # Groups
-    def add_feed_to_group(self, group_key, feed_key):
-        """
-        Adds an existing feed to a group
-        :param str group_key: Group
-        :param str feed_key: Feed to add to the group
-        """
-        path = self._compose_path("groups/{0}/add".format(group_key))
-        payload = {"feed_key": feed_key}
-        return self._post(path, payload)
-
     def create_new_group(self, group_key, group_description):
         """
         Creates a new Adafruit IO Group.
@@ -625,6 +598,26 @@ class IO_HTTP:
         path = self._compose_path("groups/{0}".format(group_key))
         return self._get(path)
 
+    def create_feed_in_group(self, group_key, feed_name):
+        """Creates a new feed in an existing group.
+        :param str group_key: Group name.
+        :param str feed_name: Name of new feed.
+
+        """
+        path = self._compose_path("groups/{0}/feeds".format(group_key))
+        payload = {"feed": {"name": feed_name}}
+        return self._post(path, payload)
+
+    def add_feed_to_group(self, group_key, feed_key):
+        """
+        Adds an existing feed to a group
+        :param str group_key: Group
+        :param str feed_key: Feed to add to the group
+        """
+        path = self._compose_path("groups/{0}/add".format(group_key))
+        payload = {"feed_key": feed_key}
+        return self._post(path, payload)
+
     # Feeds
     def get_feed(self, feed_key, detailed=False):
         """
